==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/inputs/EncryptionKeyVaultPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.inputs

import com.pulumi.azurenative.machinelearningservices.inputs.EncryptionKeyVaultPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property identityClientId For future use - The client id of the identity which will be used to access key vault.
 * @property keyIdentifier Key vault uri to access the encryption key.
 * @property keyVaultArmId The ArmId of the keyVault where the customer owned encryption key is present.
 */
public data class EncryptionKeyVaultPropertiesArgs(
    public val identityClientId: Output<String>? = null,
    public val keyIdentifier: Output<String>,
    public val keyVaultArmId: Output<String>,
) :
    ConvertibleToJava<com.pulumi.azurenative.machinelearningservices.inputs.EncryptionKeyVaultPropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.machinelearningservices.inputs.EncryptionKeyVaultPropertiesArgs =
        com.pulumi.azurenative.machinelearningservices.inputs.EncryptionKeyVaultPropertiesArgs.builder()
            .identityClientId(identityClientId?.applyValue({ args0 -> args0 }))
            .keyIdentifier(keyIdentifier.applyValue({ args0 -> args0 }))
            .keyVaultArmId(keyVaultArmId.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [EncryptionKeyVaultPropertiesArgs].
 */
@PulumiTagMarker
public class EncryptionKeyVaultPropertiesArgsBuilder internal constructor() {
    private var identityClientId: Output<String>? = null

    private var keyIdentifier: Output<String>? = null

    private var keyVaultArmId: Output<String>? = null

    /**
     * @param value For future use - The client id of the identity which will be used to access key vault.
     */
    @JvmName("clickeuvdehaxlap")
    public suspend fun identityClientId(`value`: Output<String>) {
        this.identityClientId = value
    }

    /**
     * @param value Key vault uri to access the encryption key.
     */
    @JvmName("jacyokkviisrkqeb")
    public suspend fun keyIdentifier(`value`: Output<String>) {
        this.keyIdentifier = value
    }

    /**
     * @param value The ArmId of the keyVault where the customer owned encryption key is present.
     */
    @JvmName("vlxciplksdrukfyn")
    public suspend fun keyVaultArmId(`value`: Output<String>) {
        this.keyVaultArmId = value
    }

    /**
     * @param value For future use - The client id of the identity which will be used to access key vault.
     */
    @JvmName("jlgcjlxcaibxpdjq")
    public suspend fun identityClientId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.identityClientId = mapped
    }

    /**
     * @param value Key vault uri to access the encryption key.
     */
    @JvmName("lqxfbnvqksoymujj")
    public suspend fun keyIdentifier(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.keyIdentifier = mapped
    }

    /**
     * @param value The ArmId of the keyVault where the customer owned encryption key is present.
     */
    @JvmName("iiljrrxloxosqhta")
    public suspend fun keyVaultArmId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.keyVaultArmId = mapped
    }

    internal fun build(): EncryptionKeyVaultPropertiesArgs = EncryptionKeyVaultPropertiesArgs(
        identityClientId = identityClientId,
        keyIdentifier = keyIdentifier ?: throw PulumiNullFieldException("keyIdentifier"),
        keyVaultArmId = keyVaultArmId ?: throw PulumiNullFieldException("keyVaultArmId"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/inputs/EncryptionKeyVaultPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.inputs

import com.pulumi.azurenative.machinelearningservices.inputs.EncryptionKeyVaultPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property identityClientId For future use - The client id of the identity which will be used to access key vault.
 * @property keyIdentifier Key vault uri to access the encryption key.
 * @property keyVaultArmId The ArmId of the keyVault where the customer owned encryption key is present.
 */
public data class EncryptionKeyVaultPropertiesArgs(
    public val identityClientId: Output<String>? = null,
    public val keyIdentifier: Output<String>,
    public val keyVaultArmId: Output<String>,
) :
    ConvertibleToJava<com.pulumi.azurenative.machinelearningservices.inputs.EncryptionKeyVaultPropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.machinelearningservices.inputs.EncryptionKeyVaultPropertiesArgs =
        com.pulumi.azurenative.machinelearningservices.inputs.EncryptionKeyVaultPropertiesArgs.builder()
            .identityClientId(identityClientId?.applyValue({ args0 -> args0 }))
            .keyIdentifier(keyIdentifier.applyValue({ args0 -> args0 }))
            .keyVaultArmId(keyVaultArmId.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [EncryptionKeyVaultPropertiesArgs].
 */
@PulumiTagMarker
public class EncryptionKeyVaultPropertiesArgsBuilder internal constructor() {
    private var identityClientId: Output<String>? = null

    private var keyIdentifier: Output<String>? = null

    private var keyVaultArmId: Output<String>? = null

    /**
     * @param value For future use - The client id of the identity which will be used to access key vault.
     */
    @JvmName("nbjexlsaosgqtjnx")
    public suspend fun identityClientId(`value`: Output<String>) {
        this.identityClientId = value
    }

    /**
     * @param value Key vault uri to access the encryption key.
     */
    @JvmName("eetlcugmatxueqik")
    public suspend fun keyIdentifier(`value`: Output<String>) {
        this.keyIdentifier = value
    }

    /**
     * @param value The ArmId of the keyVault where the customer owned encryption key is present.
     */
    @JvmName("aopidvqnrrhjtmec")
    public suspend fun keyVaultArmId(`value`: Output<String>) {
        this.keyVaultArmId = value
    }

    /**
     * @param value For future use - The client id of the identity which will be used to access key vault.
     */
    @JvmName("ookbxfvjekhclnva")
    public suspend fun identityClientId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.identityClientId = mapped
    }

    /**
     * @param value Key vault uri to access the encryption key.
     */
    @JvmName("olgdhlfcsqjkekqj")
    public suspend fun keyIdentifier(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.keyIdentifier = mapped
    }

    /**
     * @param value The ArmId of the keyVault where the customer owned encryption key is present.
     */
    @JvmName("pmcdiflrpspabigb")
    public suspend fun keyVaultArmId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.keyVaultArmId = mapped
    }

    internal fun build(): EncryptionKeyVaultPropertiesArgs = EncryptionKeyVaultPropertiesArgs(
        identityClientId = identityClientId,
        keyIdentifier = keyIdentifier ?: throw PulumiNullFieldException("keyIdentifier"),
        keyVaultArmId = keyVaultArmId ?: throw PulumiNullFieldException("keyVaultArmId"),
    )
}
